import React, { useState, useEffect } from 'react';
import axios from 'axios';

import { matchRoutes, renderRoutes } from 'react-router-config';
import { Link } from 'react-router-dom';

import { GithubOutlined } from '@ant-design/icons';
import ProLayout, { DefaultFooter } from '@ant-design/pro-layout';

import logo from '../assets/logo.svg';
import RightContent from '../components/GlobalHeader/RightContent';
// import config from '../routes/config';

// const noMatch = (
//   <Result
//     status={403}
//     title="403"
//     subTitle="Sorry, you are not authorized to access this page."
//     extra={<Button type="primary" />}
//   />
// );

const defaultFooterDom = (
  <DefaultFooter
    copyright={`${new Date().getFullYear()} 蚂蚁金服体验技术部出品`}
    links={[
      {
        key: 'Ant Design Pro',
        title: 'Ant Design Pro',
        href: 'https://pro.ant.design',
        blankTarget: true,
      },
      {
        key: 'github',
        title: <GithubOutlined />,
        href: 'https://github.com/ant-design/ant-design-pro',
        blankTarget: true,
      },
      {
        key: 'Ant Design',
        title: 'Ant Design',
        href: 'https://ant.design',
        blankTarget: true,
      },
    ]}
  />
);

const BasicMenu = [
  {
    path: '/dbm',
    component: 'BasicLayout',
    name: '数据库管理',
    icon: 'icon-dashboard',
    routes: [
      {
        path: '/dbm/dbInit',
        name: '数据库初始化',
      },
      {
        path: '/dbm/dbsm',
        name: '数据库标准化管理',
      },
    ],
  },
  {
    path: '/ou',
    component: 'BasicLayout',
    name: '机构与用户管理',
    icon: 'icon-dashboard',
    routes: [
      {
        path: '/ou/orgList',
        name: '机构列表',
      },
    ],
  },
  {
    path: '/basicConfig',
    component: 'BasicLayout',
    name: '基础通用配置',
    icon: 'icon-dashboard',
  },
  {
    path: '/web5',
    component: 'BasicLayout',
    name: 'Web5配置',
    icon: 'icon-dashboard',
  },
  {
    path: '/app',
    component: 'BasicLayout',
    name: '手持系统配置',
    icon: 'icon-dashboard',
  },
  {
    path: '/miniPro',
    component: 'BasicLayout',
    name: '小程序配置',
    authority: ['admin', 'user'],
    icon: 'icon-dashboard',
  },
  {
    path: '/log',
    component: 'BasicLayout',
    name: '日志管理',
    icon: 'icon-dashboard',
    routes: [
      {
        path: '/log/service',
        name: '服务日志',
      },
      {
        path: '/log/login',
        name: '登录日志',
      },
    ],
  },
];
const basicUrl = 'http://localhost:8080/Cityinterface/rest/services/OMS.svc/';

const BasicLayout = props => {
  /* eslint-disable no-unused-vars */
  const [pathname, setPathname] = useState('/welcome');
  const [menuData, setMenuData] = useState([]);
  console.log(props);
  useEffect(() => {
    fetch(`${basicUrl}U_GetOUTree?_version=9999`)
      .then(response => response.json())
      .then(data => {
        const userMode = localStorage.getItem('userMode');
        if (userMode == 'common') {
          BasicMenu.shift();
        }
        setMenuData(BasicMenu || []);
      });
  }, []);

  const handleMenuCollapse = () => {}; // get children authority
  matchRoutes(props.route.routes, props.location.pathname);
  return (
    <ProLayout
      logo={logo}
      onCollapse={handleMenuCollapse}
      onMenuHeaderClick={() => {}}
      footerRender={() => defaultFooterDom}
      rightContentRender={() => <RightContent />}
      route={
        {
          // routes: config.routes,
        }
      }
      location={{
        pathname,
      }}
      menuDataRender={menuDataProps => {
        console.log(menuDataProps);
        menuDataProps.forEach(item => {
          if (item.name == '机构列表') {
            console.log('机构列表');
            axios.get(`${basicUrl}U_GetOUTree?_version=9999`).then(result => {
              console.log(result.data);
              item.routes = [
                {
                  path: '/ou/orgList',
                  name: '机构列表11',
                },
              ];
            });
          }
        });

        return menuData;
      }}
      menuItemRender={(menuItemProps, defaultDom) => {
        if (menuItemProps.isUrl || !menuItemProps.path) {
          return defaultDom;
        }
        // console.log(menuItemProps);
        return <Link to={menuItemProps.path}>{defaultDom}</Link>;
      }}
      itemRender={(route, params, routes, paths) => {
        const first = routes.indexOf(route) === 0;
        return first ? (
          <Link to={paths.join('/')}>{route.breadcrumbName}</Link>
        ) : (
          <span>{route.breadcrumbName}</span>
        );
      }}
      {...props}
    >
      {renderRoutes(props.route.routes)}
    </ProLayout>
  );
};

export default BasicLayout;
